@@ -34,6 +34,9 @@ class ProjectConfig(IConfig):
 
     @staticmethod
     def from_dict(dic: dict):
+        if dic.get("project_name") is None:
+            return dic
+
         obj = ProjectConfig()
         obj.project_name = dic["project_name"]
         obj.data_dir = dic["data_dir"]
