@@ -3,9 +3,14 @@ from abc import abstractmethod
 from data2code_sdk.plugin.output_data import OutputData
 from typing import List
 from data2code_sdk.plugin.parsed_result import BaseParsedData
+from data2code_sdk.plugin.plugin_type import PluginType
 
 
 class IProcessorPlugin(IPlugin):
+    @staticmethod
+    def get_plugin_type():
+        return PluginType.PROCESSOR
+
     @abstractmethod
     def process(self, parsed_data: BaseParsedData, params: any, results: List[OutputData]):
         """
